@@ -1,3 +1,5 @@
+use std::error::Error;
+
 pub type ResultAuth<T> = Result<T, AuthError>;
 pub type ResultPwd<T> = Result<T, PasswordError>;
 
@@ -18,7 +20,12 @@ impl From<password_hash::Error> for PasswordError {
 
 #[derive(Debug)]
 pub enum AuthError {
+    Other(Box<dyn Error>),
     Password(PasswordError),
+    IdentityNotFound { named: String },
+    EmailNotFound { email: String },
+    UserNotFound { named: String },
+    TokenNotFound { token: String },
 }
 
 impl From<PasswordError> for AuthError {
